import { deployStack } from './cloudformation/deployStack';
import { getDeployStatus } from './cloudformation/getDeployStatus';
import { getOutputs } from './cloudformation/getOutputs';
import { removeStack } from './cloudformation/removeStack';
import { makeInlineLambda } from './lambda/makeInlineLambda';
import { makeLambda } from './lambda/makeLambda';
import { updateLambdaCode } from './lambda/updateLambdaCode';
import makeSimpleBucket from './s3/makeSimpleBucket';
import makeBucket from './s3/makeBucket';
import getFile from './s3/getFile';
import getFileUrl from './s3/getFileUrl';
import removeFile from './s3/removeFile';
import { uploadFile } from './s3/uploadFile';
import { makeLambdaEndpoint } from './apigateway/makeLambdaEndpoint';
import { makeArtifactBucket } from './codestar/cf/makeArtifactBucket';
import { makeGithubConnection } from './codestar/cf/makeGithubConnection';
import { makeBuildProject } from './codestar/cf/makeBuildProject';
import { makePipeline } from './codestar/cf/makePipeline';
import { getKeyword } from './keywords/index';
declare const _default: {
    cloudformation: {
        deployStack: typeof deployStack;
        getDeployStatus: typeof getDeployStatus;
        getOutputs: typeof getOutputs;
        removeStack: typeof removeStack;
    };
    lambda: {
        makeInlineLambda: typeof makeInlineLambda;
        makeLambda: typeof makeLambda;
        updateLambdaCode: typeof updateLambdaCode;
        invokeLambda: ({ name, payload, region }: {
            name: string;
            payload: any;
            region?: string | undefined;
        }) => Promise<any>;
    };
    s3: {
        makeBucket: typeof makeBucket;
        makeSimpleBucket: typeof makeSimpleBucket;
        getFile: typeof getFile;
        getFileUrl: typeof getFileUrl;
        removeFile: typeof removeFile;
        uploadFile: typeof uploadFile;
    };
    apigateway: {
        makeLambdaEndpoint: typeof makeLambdaEndpoint;
    };
    codestar: {
        makeArtifactBucket: typeof makeArtifactBucket;
        makeGithubConnection: typeof makeGithubConnection;
        makeBuildProject: typeof makeBuildProject;
        makePipeline: typeof makePipeline;
    };
    keywords: {
        getKeyword: typeof getKeyword;
    };
};
export default _default;
